# Datasets

### scRNA-seq

|                            Paper                             |        Dataset         |                        Download Link                         |
| :----------------------------------------------------------: | :--------------------: | :----------------------------------------------------------: |
| [Replogle et al., 2022](https://www.cell.com/cell/fulltext/S0092-8674(22)00597-9) |   K562_GWPS (61.3GB)   | [download](https://plus.figshare.com/ndownloader/files/35775507) |
| [Replogle et al., 2022](https://www.cell.com/cell/fulltext/S0092-8674(22)00597-9) | K562_ESSENTIAL (9.9GB) | [download](https://plus.figshare.com/ndownloader/files/35773219) |
| [Replogle et al., 2022](https://www.cell.com/cell/fulltext/S0092-8674(22)00597-9) |      RPE1 (8.1GB)      | [download](https://plus.figshare.com/ndownloader/files/35775606) |
| [Nadig et al., 2025](https://www.nature.com/articles/s41588-025-02169-3) |     HEPG2 (5.2GB)      | [download](https://www.ncbi.nlm.nih.gov/geo/download/?acc=GSE264667&format=file&file=GSE264667%5Fhepg2%5Fraw%5Fsinglecell%5F01%2Eh5ad) |
| [Nadig et al., 2025](https://www.nature.com/articles/s41588-025-02169-3) |     JURKAT (8.7GB)     | [download](https://www.ncbi.nlm.nih.gov/geo/download/?acc=GSE264667&format=file&file=GSE264667%5Fjurkat%5Fraw%5Fsinglecell%5F01%2Eh5ad) |

- The H1 dataset was obtained from the [Virtual Cell Challenge 2025](https://virtualcellchallenge.org/) ([download](https://storage.googleapis.com/vcc_data_prod/datasets/state/competition_support_set.zip)).
  - NOTE: ESM2 gene embeddings can also be obtained from here.


### scATAC-seq

- Cell-by-cCRE / Cell-by-peak: [Human-scATAC-Corpus](https://health.tsinghua.edu.cn/human-scatac-corpus/download.php)